@@ -1,4 +1,4 @@
-from django.urls import get_resolver
+from django.urls import get_resolver, resolve
 
 
 def get_all_urls():
@@ -11,3 +11,11 @@ def get_all_urls():
         except:
             pass
     return result
+
+
+def get_app_and_url_name(request):
+    try:
+        resolved = resolve(request.path_info)
+        return resolved.app_name, resolved.url_name
+    except:
+        return '', ''
